# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class BarSourceDataDisciplinaryHistoryArrayInner(BaseModel):
    """
    BarSourceDataDisciplinaryHistoryArrayInner
    """ # noqa: E501
    action: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    case_number: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="caseNumber")
    complaint: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = None
    contact_id: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=250)]] = Field(default=None, alias="contactId")
    date_of_action: Optional[datetime] = Field(default=None, alias="dateOfAction")
    definition: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = None
    disciplinary_decision: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="disciplinaryDecision")
    entry_date: Optional[datetime] = Field(default=None, alias="entryDate")
    information: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    link: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    note: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = None
    probation_date: Optional[datetime] = Field(default=None, alias="probationDate")
    reinstated_date: Optional[datetime] = Field(default=None, alias="reinstatedDate")
    rule: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    rule_number: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="ruleNumber")
    section_date: Optional[datetime] = Field(default=None, alias="sectionDate")
    status: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    stay_date: Optional[datetime] = Field(default=None, alias="stayDate")
    supreme_court: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="supremeCourt")
    term: Optional[Annotated[str, Field(strict=True, max_length=250)]] = None
    type_of_action: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, alias="typeOfAction")
    __properties: ClassVar[List[str]] = ["action", "caseNumber", "complaint", "contactId", "dateOfAction", "definition", "disciplinaryDecision", "entryDate", "information", "link", "note", "probationDate", "reinstatedDate", "rule", "ruleNumber", "sectionDate", "status", "stayDate", "supremeCourt", "term", "typeOfAction"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BarSourceDataDisciplinaryHistoryArrayInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if action (nullable) is None
        # and model_fields_set contains the field
        if self.action is None and "action" in self.model_fields_set:
            _dict['action'] = None

        # set to None if case_number (nullable) is None
        # and model_fields_set contains the field
        if self.case_number is None and "case_number" in self.model_fields_set:
            _dict['caseNumber'] = None

        # set to None if complaint (nullable) is None
        # and model_fields_set contains the field
        if self.complaint is None and "complaint" in self.model_fields_set:
            _dict['complaint'] = None

        # set to None if contact_id (nullable) is None
        # and model_fields_set contains the field
        if self.contact_id is None and "contact_id" in self.model_fields_set:
            _dict['contactId'] = None

        # set to None if date_of_action (nullable) is None
        # and model_fields_set contains the field
        if self.date_of_action is None and "date_of_action" in self.model_fields_set:
            _dict['dateOfAction'] = None

        # set to None if definition (nullable) is None
        # and model_fields_set contains the field
        if self.definition is None and "definition" in self.model_fields_set:
            _dict['definition'] = None

        # set to None if disciplinary_decision (nullable) is None
        # and model_fields_set contains the field
        if self.disciplinary_decision is None and "disciplinary_decision" in self.model_fields_set:
            _dict['disciplinaryDecision'] = None

        # set to None if entry_date (nullable) is None
        # and model_fields_set contains the field
        if self.entry_date is None and "entry_date" in self.model_fields_set:
            _dict['entryDate'] = None

        # set to None if information (nullable) is None
        # and model_fields_set contains the field
        if self.information is None and "information" in self.model_fields_set:
            _dict['information'] = None

        # set to None if link (nullable) is None
        # and model_fields_set contains the field
        if self.link is None and "link" in self.model_fields_set:
            _dict['link'] = None

        # set to None if note (nullable) is None
        # and model_fields_set contains the field
        if self.note is None and "note" in self.model_fields_set:
            _dict['note'] = None

        # set to None if probation_date (nullable) is None
        # and model_fields_set contains the field
        if self.probation_date is None and "probation_date" in self.model_fields_set:
            _dict['probationDate'] = None

        # set to None if reinstated_date (nullable) is None
        # and model_fields_set contains the field
        if self.reinstated_date is None and "reinstated_date" in self.model_fields_set:
            _dict['reinstatedDate'] = None

        # set to None if rule (nullable) is None
        # and model_fields_set contains the field
        if self.rule is None and "rule" in self.model_fields_set:
            _dict['rule'] = None

        # set to None if rule_number (nullable) is None
        # and model_fields_set contains the field
        if self.rule_number is None and "rule_number" in self.model_fields_set:
            _dict['ruleNumber'] = None

        # set to None if section_date (nullable) is None
        # and model_fields_set contains the field
        if self.section_date is None and "section_date" in self.model_fields_set:
            _dict['sectionDate'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if stay_date (nullable) is None
        # and model_fields_set contains the field
        if self.stay_date is None and "stay_date" in self.model_fields_set:
            _dict['stayDate'] = None

        # set to None if supreme_court (nullable) is None
        # and model_fields_set contains the field
        if self.supreme_court is None and "supreme_court" in self.model_fields_set:
            _dict['supremeCourt'] = None

        # set to None if term (nullable) is None
        # and model_fields_set contains the field
        if self.term is None and "term" in self.model_fields_set:
            _dict['term'] = None

        # set to None if type_of_action (nullable) is None
        # and model_fields_set contains the field
        if self.type_of_action is None and "type_of_action" in self.model_fields_set:
            _dict['typeOfAction'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BarSourceDataDisciplinaryHistoryArrayInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action": obj.get("action"),
            "caseNumber": obj.get("caseNumber"),
            "complaint": obj.get("complaint"),
            "contactId": obj.get("contactId"),
            "dateOfAction": obj.get("dateOfAction"),
            "definition": obj.get("definition"),
            "disciplinaryDecision": obj.get("disciplinaryDecision"),
            "entryDate": obj.get("entryDate"),
            "information": obj.get("information"),
            "link": obj.get("link"),
            "note": obj.get("note"),
            "probationDate": obj.get("probationDate"),
            "reinstatedDate": obj.get("reinstatedDate"),
            "rule": obj.get("rule"),
            "ruleNumber": obj.get("ruleNumber"),
            "sectionDate": obj.get("sectionDate"),
            "status": obj.get("status"),
            "stayDate": obj.get("stayDate"),
            "supremeCourt": obj.get("supremeCourt"),
            "term": obj.get("term"),
            "typeOfAction": obj.get("typeOfAction")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.case_analytics_api import CaseAnalyticsAPI
from unicourt.model.individual import Individual
from unicourt.model.norm_organization import NormOrganization
from unicourt.model.party_analytics_api import PartyAnalyticsAPI
from unicourt.model.related_norm_party import RelatedNormParty
from typing import Optional, Set
from typing_extensions import Self

class NormParty(BaseModel):
    """
    Norm Party
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=9)]] = 'NormParty'
    norm_party_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, alias="normPartyId")
    name: Optional[Annotated[str, Field(strict=True, max_length=500)]] = None
    party_classification_type: Optional[Annotated[str, Field(strict=True, max_length=12)]] = Field(default=None, alias="partyClassificationType")
    case_search_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, alias="caseSearchAPI")
    case_analytics_api: Optional[CaseAnalyticsAPI] = Field(default=None, alias="caseAnalyticsAPI")
    individual_data: Optional[Individual] = Field(default=None, alias="individualData")
    norm_organization_data: Optional[NormOrganization] = Field(default=None, alias="normOrganizationData")
    party_analytics_api: Optional[PartyAnalyticsAPI] = Field(default=None, alias="partyAnalyticsAPI")
    related_norm_party_array: Optional[List[RelatedNormParty]] = Field(default=None, alias="relatedNormPartyArray")
    __properties: ClassVar[List[str]] = ["object", "normPartyId", "name", "partyClassificationType", "caseSearchAPI", "caseAnalyticsAPI", "individualData", "normOrganizationData", "partyAnalyticsAPI", "relatedNormPartyArray"]

    @field_validator('party_classification_type')
    def party_classification_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Individual', 'Organization']):
            raise ValueError("must be one of enum values ('Individual', 'Organization')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NormParty from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of case_analytics_api
        if self.case_analytics_api:
            _dict['caseAnalyticsAPI'] = self.case_analytics_api.to_dict()
        # override the default output from pydantic by calling `to_dict()` of individual_data
        if self.individual_data:
            _dict['individualData'] = self.individual_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of norm_organization_data
        if self.norm_organization_data:
            _dict['normOrganizationData'] = self.norm_organization_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of party_analytics_api
        if self.party_analytics_api:
            _dict['partyAnalyticsAPI'] = self.party_analytics_api.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in related_norm_party_array (list)
        _items = []
        if self.related_norm_party_array:
            for _item in self.related_norm_party_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['relatedNormPartyArray'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NormParty from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'NormParty',
            "normPartyId": obj.get("normPartyId"),
            "name": obj.get("name"),
            "partyClassificationType": obj.get("partyClassificationType"),
            "caseSearchAPI": obj.get("caseSearchAPI"),
            "caseAnalyticsAPI": CaseAnalyticsAPI.from_dict(obj["caseAnalyticsAPI"]) if obj.get("caseAnalyticsAPI") is not None else None,
            "individualData": Individual.from_dict(obj["individualData"]) if obj.get("individualData") is not None else None,
            "normOrganizationData": NormOrganization.from_dict(obj["normOrganizationData"]) if obj.get("normOrganizationData") is not None else None,
            "partyAnalyticsAPI": PartyAnalyticsAPI.from_dict(obj["partyAnalyticsAPI"]) if obj.get("partyAnalyticsAPI") is not None else None,
            "relatedNormPartyArray": [RelatedNormParty.from_dict(_item) for _item in obj["relatedNormPartyArray"]] if obj.get("relatedNormPartyArray") is not None else None
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class CaseCountAnalyticsByCaseFiledDate(BaseModel):
    """
    CaseCountAnalyticsByCaseFiledDate
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=33)]] = 'CaseCountAnalyticsByCaseFiledDate'
    case_count: Optional[StrictInt] = Field(default=None, alias="caseCount")
    case_search_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Link to cases for this criteria.", alias="caseSearchAPI")
    grouped_by: Optional[Annotated[str, Field(strict=True, max_length=9)]] = Field(default='Yearly', alias="groupedBy")
    year: Optional[StrictInt] = None
    quarter: Optional[Annotated[str, Field(strict=True, max_length=4)]] = None
    month_string: Optional[Annotated[str, Field(strict=True, max_length=9)]] = Field(default=None, alias="monthString")
    month_int: Optional[StrictInt] = Field(default=None, alias="monthInt")
    week_of_year: Optional[StrictInt] = Field(default=None, alias="weekOfYear")
    week_of_month: Optional[StrictInt] = Field(default=None, alias="weekOfMonth")
    __properties: ClassVar[List[str]] = ["object", "caseCount", "caseSearchAPI", "groupedBy", "year", "quarter", "monthString", "monthInt", "weekOfYear", "weekOfMonth"]

    @field_validator('grouped_by')
    def grouped_by_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Yearly', 'Quarterly', 'Monthly', 'Weekly']):
            raise ValueError("must be one of enum values ('Yearly', 'Quarterly', 'Monthly', 'Weekly')")
        return value

    @field_validator('quarter')
    def quarter_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['Q1', 'Q2', 'Q3', 'Q4', 'null']):
            raise ValueError("must be one of enum values ('Q1', 'Q2', 'Q3', 'Q4', 'null')")
        return value

    @field_validator('month_string')
    def month_string_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December', 'null']):
            raise ValueError("must be one of enum values ('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CaseCountAnalyticsByCaseFiledDate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if quarter (nullable) is None
        # and model_fields_set contains the field
        if self.quarter is None and "quarter" in self.model_fields_set:
            _dict['quarter'] = None

        # set to None if month_string (nullable) is None
        # and model_fields_set contains the field
        if self.month_string is None and "month_string" in self.model_fields_set:
            _dict['monthString'] = None

        # set to None if month_int (nullable) is None
        # and model_fields_set contains the field
        if self.month_int is None and "month_int" in self.model_fields_set:
            _dict['monthInt'] = None

        # set to None if week_of_year (nullable) is None
        # and model_fields_set contains the field
        if self.week_of_year is None and "week_of_year" in self.model_fields_set:
            _dict['weekOfYear'] = None

        # set to None if week_of_month (nullable) is None
        # and model_fields_set contains the field
        if self.week_of_month is None and "week_of_month" in self.model_fields_set:
            _dict['weekOfMonth'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CaseCountAnalyticsByCaseFiledDate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'CaseCountAnalyticsByCaseFiledDate',
            "caseCount": obj.get("caseCount"),
            "caseSearchAPI": obj.get("caseSearchAPI"),
            "groupedBy": obj.get("groupedBy") if obj.get("groupedBy") is not None else 'Yearly',
            "year": obj.get("year"),
            "quarter": obj.get("quarter"),
            "monthString": obj.get("monthString"),
            "monthInt": obj.get("monthInt"),
            "weekOfYear": obj.get("weekOfYear"),
            "weekOfMonth": obj.get("weekOfMonth")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, field_validator
from typing import Optional
from typing_extensions import Annotated
from unicourt.model.case_search_response import CaseSearchResponse

from unicourt.api_client import ApiClient, RequestSerialized
from unicourt.api_response import ApiResponse
from unicourt.rest import RESTResponseType


class CaseSearchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def search_cases(
        self,
        q: Annotated[str, Field(min_length=3, strict=True, max_length=2000, description="Query parameter for keyword expressions.</a> ")],
        sort: Annotated[Optional[Annotated[str, Field(min_length=9, strict=True, max_length=9)]], Field(description="Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.")] = None,
        order: Annotated[Optional[Annotated[str, Field(min_length=3, strict=True, max_length=4)]], Field(description="Query parameter specifying whether search result are sorted in ascending or descending order.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CaseSearchResponse:
        """Case search.

        This endpoint retrieves cases according to keyword expressions you provide. <br> Keyword expressions are constructed according to the rules described below. <br><br> This API supports multiple use cases:   - Search for multiple keywords  `Google OR Facebook`.   - Search within particular attributes.   - Relational search using terms and connectors.   - And much more. ----  ## Allowed Connectors in Keyword Expressions | Connector | Description  | Example | | ------| ------|------| | **AND** |Find cases containing each of the terms joined by AND connectors.|**personal AND injury**| | **OR**  |Find cases containing any of the terms joined by OR connectors.|**order OR decision**| | **NOT** |Find cases that do not contain the specified term.|**personal AND NOT injury**.  Find cases with the word “personal” and not “injury”.| | **“[phrase]”** |Find the exact phrase placed between the quotation marks.|**\"personal injury”**| | **~**  |Find cases in which the specified words appear near each other. For example, \"personal injury\" ~ 5 targets cases in which the word \"personal\" appears within 5 words of the word \"injury\".|**“personal injury” ~ 5** - Find cases with “personal” within five words of “injury”. | | **( … )** |Specifies the order in which connectors are to be appliied in a keyword expression.| **personal AND (injury OR fall)** - Find cases with the word personal injury or personal fall.|  <br><br> ## Fields and Connectors Searching | Filed | Description  | Example | | ------| ------|------| |**caseNumber** |Find cases with the specified case number (i.e., docket number).| **caseNumber:\"2020-L-007212\"** - Find cases whose case number matches given case number number.| |**caseName** |Find cases with the specified case title.| **caseName:\"THOMAS P. CARNEY, INC. VS BEHLER JAMES Et Al\"** - Find cases whose case name matches given terms.| |**Court**|Find cases in the specified court.|**(Court:(name:(New York)))** - Find cases in New York state.<br>| |**CaseStatus**|Find cases witih the specified case status.|**(CaseStatus:(name:Disposed))** - All disposed cases.<br>| |**CaseType**|Find cases of the specified case type. | **(CaseType:(name:Property))** - Cases with case type “property”.| |**Party** | Find cases involving the specified party.| **(Party:(name:Apple))** - Find cases involving Apple. | |**partyId**|Find cases involving a party with the specified partyId value.|**(Party:(partyId:\"PRTYgu1ffe866484c2\"))**| |**PartyRole** | Find cases in which at least one party has the specified party role. | **(Party:((PartyRole:(name:\"plaintiff\"))))** - Find cases with party role “plaintiff”.<br><br> **(Party:((PartyRole:(name:defendant)) AND (AttorneyRepresentationType:(name:(Attorney represented)))))** - Find cases where a party is acting as defendant and represented by an attorney.| |**AttorneyRepresentationType**| Find cases in which at least one party has the specified attorney representation type.|**(Party:(AttorneyRepresentationType:(name:\"attorney represented\")))** - Find cases where a party is represented by an attorney. | |**Attorney** | Find cases involving the specified attorney. | **(Attorney:(name:\"David Boies\"))** - Find cases involving the attorney David Boies. | |**AttorneyType**|Find cases involving at least one attorney of the specified attorney type.|**(Attorney:((AttorneyType:(name:\"Lead Attorney\"))))**| |**Judge** |Find cases involving the specified judge. | **(Judge:(name:\"Posner\"))** - Find cases involving Judge Posner.| |**JudgeType**|Find cases involving at least one judge of the specified judge type.|**(Judge:((JudgeType:(name:\"Magistrate\"))))**| |**CaseStats**|Find cases with the specified case statistics.|**(CaseStats:(partyCount:[10 TO 100]))** - Find cases involving 10 to 100 parties.<br>**(CaseStats:(attorneyCount:[2 TO 40]))** - Find cases involving 2 to 40 attorneys.<br>**(CaseStats:(judgeCount:[\\* TO 2]))** - Find cases involving up to 2 judges. <br>**(CaseStats:(docketEntryCount:[10 TO 100]))** - Find cases having 10 to 100 docket_entries. <br>**(CaseStats:(allCaseDocumentCount:[10 TO 100]))** - Find cases having 10 to 100 documents. | |**filedDate** | Find cases that were filed on the specified date or within the specified date range. | **filedDate:[2020-03-15 TO 2021-12-01]** - Find the most recently filed cases between March 15, 2020 and December 1, 2021 (inclusive). | |**lastFetchDate**| Find cases in which UniCourt last checked for updates on the specified date or within the specified date range. |**(lastFetchDate:[now-60d TO \\*\\])** - Find cases that were updated by UniCourt in the last 60 days. | |**lastFetchDateWithUpdates**|Find cases in which UniCourt last detected an update on the specified date or within the specified date range.|**(lastFetchDateWithUpdates:[now-6d TO \\*\\])** - Find cases for the changes found on court site in last 6 days.| |**participantsLastFetchDate**|Find cases in which information cocnerning participants was last updated on the specified date or within the specified date range.|**(participantsLastFetchDate:[now-6d TO \\*\\])** - Find cases where the participant's information was updated in last 6 days.| |**DocketEntry**|Find cases in which at least one docket entry contains the specified text.|**(DocketEntry:(text:(Motion to Compel Responses) AND docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00]))** - Find cases with docket text “Motion to Compel Responses” and action date between 2020-01-01 and 2020-05-01.| |**docketEntryDate**|Find cases in which at least one docket entry was made on the specified date or within the specified date range.|**(DocketEntry:(docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00])) AND (CaseStats:(allCaseDocumentCount:[0 TO 10]))** - Find cases with docket action date between 2020-01-01 and 2020-05-01 having up to 10 documents associated with it.| |**HearingDate**| Find cases with at least one hearing scheduled for the specified date or within the specified date range.|**(Hearing:(hearingDate:[now TO now+10d]))** - Find cases where hearing is scheduled in next 10 days.| |**HearingDate**| Search for cases where hearing is going to happen in 10 to 20days.|**(Hearing:(hearingDate:[now+10d TO now+20d]))** - Find cases where hearing is scheduled in next 10 to 20 days.| |**JurisdictionGeo**|Find cases in which the law of the specified state governs.|**(JurisdictionGeo:(state:\"New York\"))**- Find cases where Jurisdiction is New York state.| |**Party Address Exists**|Find cases with Party addresses.|**(Party:(Contact:(Address:(stateName:\\*))))**- Returns only those cases that have addresses for parties.| |**Document**|Find cases with specific document name and preview is available for the document.|**(CaseDocument:(name:\"civil case cover sheet\" AND isPreviewAvailable:true))**- Returns cases with document civil case cover sheet and preview is available.|  <br><br> --- ## Party Sub Filter Examples |Example |Explanation | |---|---| |**(Party:(name:google AND (PartyRole:(name:\"plaintiff\"))))**|Find cases involving at least one plaintiff whose name contains the term \"Google\".| |**(Party:(name:\"OTELIA PEREIDA\" AND (AttorneyRepresentationType:(name:\"Attorney represented\")))) AND (Attorney:(name:\"Law Offices of Todd M Friedman\"))**|Find cases where the Party is *OTELIA PEREIDA* and is represented by the attorney *Law Offices of Todd M Friedman*.|  --- ### All query parameters supported for this API can be found in below schema section. Schema -->  CaseSearchQueryObject 

        :param q: Query parameter for keyword expressions.</a>  (required)
        :type q: str
        :param sort: Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.
        :type sort: str
        :param order: Query parameter specifying whether search result are sorted in ascending or descending order.
        :type order: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_serialize(
            q=q,
            sort=sort,
            order=order,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_cases_with_http_info(
        self,
        q: Annotated[str, Field(min_length=3, strict=True, max_length=2000, description="Query parameter for keyword expressions.</a> ")],
        sort: Annotated[Optional[Annotated[str, Field(min_length=9, strict=True, max_length=9)]], Field(description="Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.")] = None,
        order: Annotated[Optional[Annotated[str, Field(min_length=3, strict=True, max_length=4)]], Field(description="Query parameter specifying whether search result are sorted in ascending or descending order.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseSearchResponse]:
        """Case search.

        This endpoint retrieves cases according to keyword expressions you provide. <br> Keyword expressions are constructed according to the rules described below. <br><br> This API supports multiple use cases:   - Search for multiple keywords  `Google OR Facebook`.   - Search within particular attributes.   - Relational search using terms and connectors.   - And much more. ----  ## Allowed Connectors in Keyword Expressions | Connector | Description  | Example | | ------| ------|------| | **AND** |Find cases containing each of the terms joined by AND connectors.|**personal AND injury**| | **OR**  |Find cases containing any of the terms joined by OR connectors.|**order OR decision**| | **NOT** |Find cases that do not contain the specified term.|**personal AND NOT injury**.  Find cases with the word “personal” and not “injury”.| | **“[phrase]”** |Find the exact phrase placed between the quotation marks.|**\"personal injury”**| | **~**  |Find cases in which the specified words appear near each other. For example, \"personal injury\" ~ 5 targets cases in which the word \"personal\" appears within 5 words of the word \"injury\".|**“personal injury” ~ 5** - Find cases with “personal” within five words of “injury”. | | **( … )** |Specifies the order in which connectors are to be appliied in a keyword expression.| **personal AND (injury OR fall)** - Find cases with the word personal injury or personal fall.|  <br><br> ## Fields and Connectors Searching | Filed | Description  | Example | | ------| ------|------| |**caseNumber** |Find cases with the specified case number (i.e., docket number).| **caseNumber:\"2020-L-007212\"** - Find cases whose case number matches given case number number.| |**caseName** |Find cases with the specified case title.| **caseName:\"THOMAS P. CARNEY, INC. VS BEHLER JAMES Et Al\"** - Find cases whose case name matches given terms.| |**Court**|Find cases in the specified court.|**(Court:(name:(New York)))** - Find cases in New York state.<br>| |**CaseStatus**|Find cases witih the specified case status.|**(CaseStatus:(name:Disposed))** - All disposed cases.<br>| |**CaseType**|Find cases of the specified case type. | **(CaseType:(name:Property))** - Cases with case type “property”.| |**Party** | Find cases involving the specified party.| **(Party:(name:Apple))** - Find cases involving Apple. | |**partyId**|Find cases involving a party with the specified partyId value.|**(Party:(partyId:\"PRTYgu1ffe866484c2\"))**| |**PartyRole** | Find cases in which at least one party has the specified party role. | **(Party:((PartyRole:(name:\"plaintiff\"))))** - Find cases with party role “plaintiff”.<br><br> **(Party:((PartyRole:(name:defendant)) AND (AttorneyRepresentationType:(name:(Attorney represented)))))** - Find cases where a party is acting as defendant and represented by an attorney.| |**AttorneyRepresentationType**| Find cases in which at least one party has the specified attorney representation type.|**(Party:(AttorneyRepresentationType:(name:\"attorney represented\")))** - Find cases where a party is represented by an attorney. | |**Attorney** | Find cases involving the specified attorney. | **(Attorney:(name:\"David Boies\"))** - Find cases involving the attorney David Boies. | |**AttorneyType**|Find cases involving at least one attorney of the specified attorney type.|**(Attorney:((AttorneyType:(name:\"Lead Attorney\"))))**| |**Judge** |Find cases involving the specified judge. | **(Judge:(name:\"Posner\"))** - Find cases involving Judge Posner.| |**JudgeType**|Find cases involving at least one judge of the specified judge type.|**(Judge:((JudgeType:(name:\"Magistrate\"))))**| |**CaseStats**|Find cases with the specified case statistics.|**(CaseStats:(partyCount:[10 TO 100]))** - Find cases involving 10 to 100 parties.<br>**(CaseStats:(attorneyCount:[2 TO 40]))** - Find cases involving 2 to 40 attorneys.<br>**(CaseStats:(judgeCount:[\\* TO 2]))** - Find cases involving up to 2 judges. <br>**(CaseStats:(docketEntryCount:[10 TO 100]))** - Find cases having 10 to 100 docket_entries. <br>**(CaseStats:(allCaseDocumentCount:[10 TO 100]))** - Find cases having 10 to 100 documents. | |**filedDate** | Find cases that were filed on the specified date or within the specified date range. | **filedDate:[2020-03-15 TO 2021-12-01]** - Find the most recently filed cases between March 15, 2020 and December 1, 2021 (inclusive). | |**lastFetchDate**| Find cases in which UniCourt last checked for updates on the specified date or within the specified date range. |**(lastFetchDate:[now-60d TO \\*\\])** - Find cases that were updated by UniCourt in the last 60 days. | |**lastFetchDateWithUpdates**|Find cases in which UniCourt last detected an update on the specified date or within the specified date range.|**(lastFetchDateWithUpdates:[now-6d TO \\*\\])** - Find cases for the changes found on court site in last 6 days.| |**participantsLastFetchDate**|Find cases in which information cocnerning participants was last updated on the specified date or within the specified date range.|**(participantsLastFetchDate:[now-6d TO \\*\\])** - Find cases where the participant's information was updated in last 6 days.| |**DocketEntry**|Find cases in which at least one docket entry contains the specified text.|**(DocketEntry:(text:(Motion to Compel Responses) AND docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00]))** - Find cases with docket text “Motion to Compel Responses” and action date between 2020-01-01 and 2020-05-01.| |**docketEntryDate**|Find cases in which at least one docket entry was made on the specified date or within the specified date range.|**(DocketEntry:(docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00])) AND (CaseStats:(allCaseDocumentCount:[0 TO 10]))** - Find cases with docket action date between 2020-01-01 and 2020-05-01 having up to 10 documents associated with it.| |**HearingDate**| Find cases with at least one hearing scheduled for the specified date or within the specified date range.|**(Hearing:(hearingDate:[now TO now+10d]))** - Find cases where hearing is scheduled in next 10 days.| |**HearingDate**| Search for cases where hearing is going to happen in 10 to 20days.|**(Hearing:(hearingDate:[now+10d TO now+20d]))** - Find cases where hearing is scheduled in next 10 to 20 days.| |**JurisdictionGeo**|Find cases in which the law of the specified state governs.|**(JurisdictionGeo:(state:\"New York\"))**- Find cases where Jurisdiction is New York state.| |**Party Address Exists**|Find cases with Party addresses.|**(Party:(Contact:(Address:(stateName:\\*))))**- Returns only those cases that have addresses for parties.| |**Document**|Find cases with specific document name and preview is available for the document.|**(CaseDocument:(name:\"civil case cover sheet\" AND isPreviewAvailable:true))**- Returns cases with document civil case cover sheet and preview is available.|  <br><br> --- ## Party Sub Filter Examples |Example |Explanation | |---|---| |**(Party:(name:google AND (PartyRole:(name:\"plaintiff\"))))**|Find cases involving at least one plaintiff whose name contains the term \"Google\".| |**(Party:(name:\"OTELIA PEREIDA\" AND (AttorneyRepresentationType:(name:\"Attorney represented\")))) AND (Attorney:(name:\"Law Offices of Todd M Friedman\"))**|Find cases where the Party is *OTELIA PEREIDA* and is represented by the attorney *Law Offices of Todd M Friedman*.|  --- ### All query parameters supported for this API can be found in below schema section. Schema -->  CaseSearchQueryObject 

        :param q: Query parameter for keyword expressions.</a>  (required)
        :type q: str
        :param sort: Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.
        :type sort: str
        :param order: Query parameter specifying whether search result are sorted in ascending or descending order.
        :type order: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_serialize(
            q=q,
            sort=sort,
            order=order,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_cases_without_preload_content(
        self,
        q: Annotated[str, Field(min_length=3, strict=True, max_length=2000, description="Query parameter for keyword expressions.</a> ")],
        sort: Annotated[Optional[Annotated[str, Field(min_length=9, strict=True, max_length=9)]], Field(description="Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.")] = None,
        order: Annotated[Optional[Annotated[str, Field(min_length=3, strict=True, max_length=4)]], Field(description="Query parameter specifying whether search result are sorted in ascending or descending order.")] = None,
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Case search.

        This endpoint retrieves cases according to keyword expressions you provide. <br> Keyword expressions are constructed according to the rules described below. <br><br> This API supports multiple use cases:   - Search for multiple keywords  `Google OR Facebook`.   - Search within particular attributes.   - Relational search using terms and connectors.   - And much more. ----  ## Allowed Connectors in Keyword Expressions | Connector | Description  | Example | | ------| ------|------| | **AND** |Find cases containing each of the terms joined by AND connectors.|**personal AND injury**| | **OR**  |Find cases containing any of the terms joined by OR connectors.|**order OR decision**| | **NOT** |Find cases that do not contain the specified term.|**personal AND NOT injury**.  Find cases with the word “personal” and not “injury”.| | **“[phrase]”** |Find the exact phrase placed between the quotation marks.|**\"personal injury”**| | **~**  |Find cases in which the specified words appear near each other. For example, \"personal injury\" ~ 5 targets cases in which the word \"personal\" appears within 5 words of the word \"injury\".|**“personal injury” ~ 5** - Find cases with “personal” within five words of “injury”. | | **( … )** |Specifies the order in which connectors are to be appliied in a keyword expression.| **personal AND (injury OR fall)** - Find cases with the word personal injury or personal fall.|  <br><br> ## Fields and Connectors Searching | Filed | Description  | Example | | ------| ------|------| |**caseNumber** |Find cases with the specified case number (i.e., docket number).| **caseNumber:\"2020-L-007212\"** - Find cases whose case number matches given case number number.| |**caseName** |Find cases with the specified case title.| **caseName:\"THOMAS P. CARNEY, INC. VS BEHLER JAMES Et Al\"** - Find cases whose case name matches given terms.| |**Court**|Find cases in the specified court.|**(Court:(name:(New York)))** - Find cases in New York state.<br>| |**CaseStatus**|Find cases witih the specified case status.|**(CaseStatus:(name:Disposed))** - All disposed cases.<br>| |**CaseType**|Find cases of the specified case type. | **(CaseType:(name:Property))** - Cases with case type “property”.| |**Party** | Find cases involving the specified party.| **(Party:(name:Apple))** - Find cases involving Apple. | |**partyId**|Find cases involving a party with the specified partyId value.|**(Party:(partyId:\"PRTYgu1ffe866484c2\"))**| |**PartyRole** | Find cases in which at least one party has the specified party role. | **(Party:((PartyRole:(name:\"plaintiff\"))))** - Find cases with party role “plaintiff”.<br><br> **(Party:((PartyRole:(name:defendant)) AND (AttorneyRepresentationType:(name:(Attorney represented)))))** - Find cases where a party is acting as defendant and represented by an attorney.| |**AttorneyRepresentationType**| Find cases in which at least one party has the specified attorney representation type.|**(Party:(AttorneyRepresentationType:(name:\"attorney represented\")))** - Find cases where a party is represented by an attorney. | |**Attorney** | Find cases involving the specified attorney. | **(Attorney:(name:\"David Boies\"))** - Find cases involving the attorney David Boies. | |**AttorneyType**|Find cases involving at least one attorney of the specified attorney type.|**(Attorney:((AttorneyType:(name:\"Lead Attorney\"))))**| |**Judge** |Find cases involving the specified judge. | **(Judge:(name:\"Posner\"))** - Find cases involving Judge Posner.| |**JudgeType**|Find cases involving at least one judge of the specified judge type.|**(Judge:((JudgeType:(name:\"Magistrate\"))))**| |**CaseStats**|Find cases with the specified case statistics.|**(CaseStats:(partyCount:[10 TO 100]))** - Find cases involving 10 to 100 parties.<br>**(CaseStats:(attorneyCount:[2 TO 40]))** - Find cases involving 2 to 40 attorneys.<br>**(CaseStats:(judgeCount:[\\* TO 2]))** - Find cases involving up to 2 judges. <br>**(CaseStats:(docketEntryCount:[10 TO 100]))** - Find cases having 10 to 100 docket_entries. <br>**(CaseStats:(allCaseDocumentCount:[10 TO 100]))** - Find cases having 10 to 100 documents. | |**filedDate** | Find cases that were filed on the specified date or within the specified date range. | **filedDate:[2020-03-15 TO 2021-12-01]** - Find the most recently filed cases between March 15, 2020 and December 1, 2021 (inclusive). | |**lastFetchDate**| Find cases in which UniCourt last checked for updates on the specified date or within the specified date range. |**(lastFetchDate:[now-60d TO \\*\\])** - Find cases that were updated by UniCourt in the last 60 days. | |**lastFetchDateWithUpdates**|Find cases in which UniCourt last detected an update on the specified date or within the specified date range.|**(lastFetchDateWithUpdates:[now-6d TO \\*\\])** - Find cases for the changes found on court site in last 6 days.| |**participantsLastFetchDate**|Find cases in which information cocnerning participants was last updated on the specified date or within the specified date range.|**(participantsLastFetchDate:[now-6d TO \\*\\])** - Find cases where the participant's information was updated in last 6 days.| |**DocketEntry**|Find cases in which at least one docket entry contains the specified text.|**(DocketEntry:(text:(Motion to Compel Responses) AND docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00]))** - Find cases with docket text “Motion to Compel Responses” and action date between 2020-01-01 and 2020-05-01.| |**docketEntryDate**|Find cases in which at least one docket entry was made on the specified date or within the specified date range.|**(DocketEntry:(docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00])) AND (CaseStats:(allCaseDocumentCount:[0 TO 10]))** - Find cases with docket action date between 2020-01-01 and 2020-05-01 having up to 10 documents associated with it.| |**HearingDate**| Find cases with at least one hearing scheduled for the specified date or within the specified date range.|**(Hearing:(hearingDate:[now TO now+10d]))** - Find cases where hearing is scheduled in next 10 days.| |**HearingDate**| Search for cases where hearing is going to happen in 10 to 20days.|**(Hearing:(hearingDate:[now+10d TO now+20d]))** - Find cases where hearing is scheduled in next 10 to 20 days.| |**JurisdictionGeo**|Find cases in which the law of the specified state governs.|**(JurisdictionGeo:(state:\"New York\"))**- Find cases where Jurisdiction is New York state.| |**Party Address Exists**|Find cases with Party addresses.|**(Party:(Contact:(Address:(stateName:\\*))))**- Returns only those cases that have addresses for parties.| |**Document**|Find cases with specific document name and preview is available for the document.|**(CaseDocument:(name:\"civil case cover sheet\" AND isPreviewAvailable:true))**- Returns cases with document civil case cover sheet and preview is available.|  <br><br> --- ## Party Sub Filter Examples |Example |Explanation | |---|---| |**(Party:(name:google AND (PartyRole:(name:\"plaintiff\"))))**|Find cases involving at least one plaintiff whose name contains the term \"Google\".| |**(Party:(name:\"OTELIA PEREIDA\" AND (AttorneyRepresentationType:(name:\"Attorney represented\")))) AND (Attorney:(name:\"Law Offices of Todd M Friedman\"))**|Find cases where the Party is *OTELIA PEREIDA* and is represented by the attorney *Law Offices of Todd M Friedman*.|  --- ### All query parameters supported for this API can be found in below schema section. Schema -->  CaseSearchQueryObject 

        :param q: Query parameter for keyword expressions.</a>  (required)
        :type q: str
        :param sort: Query parameter specifying how results are to be sorted. Results can be sorted according to filedDate or relevancy.
        :type sort: str
        :param order: Query parameter specifying whether search result are sorted in ascending or descending order.
        :type order: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_serialize(
            q=q,
            sort=sort,
            order=order,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_cases_serialize(
        self,
        q,
        sort,
        order,
        page_number,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if order is not None:
            
            _query_params.append(('order', order))
            
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/caseSearch',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def search_cases_by_id(
        self,
        case_search_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case Search information for the given caseSearchId.")],
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CaseSearchResponse:
        """Case search results for a given caseSearchId.

        Retrieve the search results corresponding to the specified caseSearchId value. 

        :param case_search_id: Case Search information for the given caseSearchId. (required)
        :type case_search_id: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_by_id_serialize(
            case_search_id=case_search_id,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
            '404': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def search_cases_by_id_with_http_info(
        self,
        case_search_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case Search information for the given caseSearchId.")],
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CaseSearchResponse]:
        """Case search results for a given caseSearchId.

        Retrieve the search results corresponding to the specified caseSearchId value. 

        :param case_search_id: Case Search information for the given caseSearchId. (required)
        :type case_search_id: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_by_id_serialize(
            case_search_id=case_search_id,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
            '404': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def search_cases_by_id_without_preload_content(
        self,
        case_search_id: Annotated[str, Field(min_length=18, strict=True, max_length=18, description="Case Search information for the given caseSearchId.")],
        page_number: Annotated[Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]], Field(description="The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 ")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Case search results for a given caseSearchId.

        Retrieve the search results corresponding to the specified caseSearchId value. 

        :param case_search_id: Case Search information for the given caseSearchId. (required)
        :type case_search_id: str
        :param page_number: The page number of the desired page of results. - Minimum: 1 - Maximum: 1000 
        :type page_number: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._search_cases_by_id_serialize(
            case_search_id=case_search_id,
            page_number=page_number,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CaseSearchResponse",
            '400': "Exception",
            '404': "Exception",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _search_cases_by_id_serialize(
        self,
        case_search_id,
        page_number,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if case_search_id is not None:
            _path_params['caseSearchId'] = case_search_id
        # process the query parameters
        if page_number is not None:
            
            _query_params.append(('pageNumber', page_number))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/caseSearch/{caseSearchId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.additional_levels import AdditionalLevels
from typing import Optional, Set
from typing_extensions import Self

class Court(BaseModel):
    """
    Court
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=5, strict=True, max_length=5)]] = 'Court'
    court_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, alias="courtId")
    court_type_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, alias="courtTypeId")
    court_system_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, alias="courtSystemId")
    type: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = None
    system: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = None
    name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = None
    name_aka: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="nameAka")
    additional_levels: Optional[AdditionalLevels] = Field(default=None, alias="additionalLevels")
    container_type: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="containerType")
    container: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = None
    created_date: Optional[datetime] = Field(default=None, description="The date and time when the Court was first created. This date and time is in UTC. Formatted as YYYY-MM-DD HH:MM:SS.", alias="createdDate")
    jurisdiction_geo_for_court_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="jurisdictionGeoForCourtAPI")
    court_locations_for_court_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="courtLocationsForCourtAPI")
    appeal_courts_for_court_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=255)]] = Field(default=None, alias="appealCourtsForCourtAPI")
    court_service_status_api: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=2048)]] = Field(default=None, alias="courtServiceStatusAPI")
    __properties: ClassVar[List[str]] = ["object", "courtId", "courtTypeId", "courtSystemId", "type", "system", "name", "nameAka", "additionalLevels", "containerType", "container", "createdDate", "jurisdictionGeoForCourtAPI", "courtLocationsForCourtAPI", "appealCourtsForCourtAPI", "courtServiceStatusAPI"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Court from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of additional_levels
        if self.additional_levels:
            _dict['additionalLevels'] = self.additional_levels.to_dict()
        # set to None if container_type (nullable) is None
        # and model_fields_set contains the field
        if self.container_type is None and "container_type" in self.model_fields_set:
            _dict['containerType'] = None

        # set to None if container (nullable) is None
        # and model_fields_set contains the field
        if self.container is None and "container" in self.model_fields_set:
            _dict['container'] = None

        # set to None if jurisdiction_geo_for_court_api (nullable) is None
        # and model_fields_set contains the field
        if self.jurisdiction_geo_for_court_api is None and "jurisdiction_geo_for_court_api" in self.model_fields_set:
            _dict['jurisdictionGeoForCourtAPI'] = None

        # set to None if court_locations_for_court_api (nullable) is None
        # and model_fields_set contains the field
        if self.court_locations_for_court_api is None and "court_locations_for_court_api" in self.model_fields_set:
            _dict['courtLocationsForCourtAPI'] = None

        # set to None if appeal_courts_for_court_api (nullable) is None
        # and model_fields_set contains the field
        if self.appeal_courts_for_court_api is None and "appeal_courts_for_court_api" in self.model_fields_set:
            _dict['appealCourtsForCourtAPI'] = None

        # set to None if court_service_status_api (nullable) is None
        # and model_fields_set contains the field
        if self.court_service_status_api is None and "court_service_status_api" in self.model_fields_set:
            _dict['courtServiceStatusAPI'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Court from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'Court',
            "courtId": obj.get("courtId"),
            "courtTypeId": obj.get("courtTypeId"),
            "courtSystemId": obj.get("courtSystemId"),
            "type": obj.get("type"),
            "system": obj.get("system"),
            "name": obj.get("name"),
            "nameAka": obj.get("nameAka"),
            "additionalLevels": AdditionalLevels.from_dict(obj["additionalLevels"]) if obj.get("additionalLevels") is not None else None,
            "containerType": obj.get("containerType"),
            "container": obj.get("container"),
            "createdDate": obj.get("createdDate"),
            "jurisdictionGeoForCourtAPI": obj.get("jurisdictionGeoForCourtAPI"),
            "courtLocationsForCourtAPI": obj.get("courtLocationsForCourtAPI"),
            "appealCourtsForCourtAPI": obj.get("appealCourtsForCourtAPI"),
            "courtServiceStatusAPI": obj.get("courtServiceStatusAPI")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ServiceHistory(BaseModel):
    """
    A timeline of courts where the judge has been employed.
    """ # noqa: E501
    object: Optional[Annotated[str, Field(strict=True, max_length=14)]] = 'ServiceHistory'
    appointed_by: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="The President-in-charge of the Judges appointment.", alias="appointedBy")
    reason_for_termination: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="The reason for the Judges termination for the current position.", alias="reasonForTermination")
    source_court: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="The court served by the Judge. The court is taken from source.", alias="sourceCourt")
    title: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Title held by the Judge.")
    from_year: Optional[StrictInt] = Field(default=None, description="The year in which the Judge began practicing in his current service.", alias="fromYear")
    to_year: Optional[StrictInt] = Field(default=None, description="The year in which the Judge stoped practicing in his current service.", alias="toYear")
    from_date: Optional[datetime] = Field(default=None, description="The year in which the Judge began practicing in his current service.", alias="fromDate")
    to_date: Optional[datetime] = Field(default=None, description="The year in which the Judge stoped practicing in his current service.", alias="toDate")
    is_visible: Optional[StrictBool] = Field(default=None, description="Boolean indicating if the service history  is visible or not.", alias="isVisible")
    __properties: ClassVar[List[str]] = ["object", "appointedBy", "reasonForTermination", "sourceCourt", "title", "fromYear", "toYear", "fromDate", "toDate", "isVisible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceHistory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if appointed_by (nullable) is None
        # and model_fields_set contains the field
        if self.appointed_by is None and "appointed_by" in self.model_fields_set:
            _dict['appointedBy'] = None

        # set to None if reason_for_termination (nullable) is None
        # and model_fields_set contains the field
        if self.reason_for_termination is None and "reason_for_termination" in self.model_fields_set:
            _dict['reasonForTermination'] = None

        # set to None if source_court (nullable) is None
        # and model_fields_set contains the field
        if self.source_court is None and "source_court" in self.model_fields_set:
            _dict['sourceCourt'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if from_year (nullable) is None
        # and model_fields_set contains the field
        if self.from_year is None and "from_year" in self.model_fields_set:
            _dict['fromYear'] = None

        # set to None if to_year (nullable) is None
        # and model_fields_set contains the field
        if self.to_year is None and "to_year" in self.model_fields_set:
            _dict['toYear'] = None

        # set to None if from_date (nullable) is None
        # and model_fields_set contains the field
        if self.from_date is None and "from_date" in self.model_fields_set:
            _dict['fromDate'] = None

        # set to None if to_date (nullable) is None
        # and model_fields_set contains the field
        if self.to_date is None and "to_date" in self.model_fields_set:
            _dict['toDate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceHistory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'ServiceHistory',
            "appointedBy": obj.get("appointedBy"),
            "reasonForTermination": obj.get("reasonForTermination"),
            "sourceCourt": obj.get("sourceCourt"),
            "title": obj.get("title"),
            "fromYear": obj.get("fromYear"),
            "toYear": obj.get("toYear"),
            "fromDate": obj.get("fromDate"),
            "toDate": obj.get("toDate"),
            "isVisible": obj.get("isVisible")
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.attorneys import Attorneys
from unicourt.model.case_cause_of_action import CaseCauseOfAction
from unicourt.model.case_charge import CaseCharge
from unicourt.model.case_documents import CaseDocuments
from unicourt.model.case_stats import CaseStats
from unicourt.model.case_status import CaseStatus
from unicourt.model.case_type import CaseType
from unicourt.model.court import Court
from unicourt.model.court_location import CourtLocation
from unicourt.model.docket_entries import DocketEntries
from unicourt.model.hearings import Hearings
from unicourt.model.judges import Judges
from unicourt.model.parties import Parties
from unicourt.model.related_cases import RelatedCases
from unicourt.model.source_case_data import SourceCaseData
from typing import Optional, Set
from typing_extensions import Self

class Case(BaseModel):
    """
    Case
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=4, strict=True, max_length=4)]] = Field(default='Case', description="Name of the object")
    case_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="Unique identifier of Case.", alias="caseId")
    url: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="URL to the case page in UniCourt Application.")
    case_number: Optional[Annotated[str, Field(min_length=3, strict=True, max_length=50)]] = Field(default=None, description="Case number as provided by Court.", alias="caseNumber")
    case_name: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="Case name as provided by Court.", alias="caseName")
    filed_date: Optional[datetime] = Field(default=None, description="Filing date for the case provided by the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz", alias="filedDate")
    has_only_meta_info: Optional[StrictBool] = Field(default=None, description="This field determines if this case object has only meta information. If the value is true and if the full information is required you would need to call the updateCase API.", alias="hasOnlyMetaInfo")
    court_service_status_id: Optional[Annotated[str, Field(min_length=18, strict=True, max_length=18)]] = Field(default=None, description="Court Service Status ID of the requested case where we can use it to get the service status", alias="courtServiceStatusId")
    court_service_status_api: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="API to get the service statuses of the given case.", alias="courtServiceStatusAPI")
    court: Optional[Court] = None
    court_location: Optional[CourtLocation] = Field(default=None, alias="courtLocation")
    case_type: Optional[CaseType] = Field(default=None, alias="caseType")
    charge_array: Optional[List[CaseCharge]] = Field(default=None, description="Array of charges that are added to this case.", alias="chargeArray")
    case_status: Optional[CaseStatus] = Field(default=None, alias="caseStatus")
    cause_of_action_array: Optional[List[CaseCauseOfAction]] = Field(default=None, description="Array of cause of Actions that are added to this case.", alias="causeOfActionArray")
    first_fetch_date: Optional[datetime] = Field(default=None, description="The date and time when the case was first fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,.", alias="firstFetchDate")
    last_fetch_date: Optional[datetime] = Field(default=None, description="The date and time when the case was last fetched from the Court. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: It is not necessary that every time the case is fetched from Court we find changes in the case information. It could be that we already have the latest information from the Court and no changes exist.", alias="lastFetchDate")
    last_fetch_date_with_updates: Optional[datetime] = Field(default=None, description="The date and time when the case was last fetched from the Court where we found changes in the case information. This date and time is in UTC. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz,", alias="lastFetchDateWithUpdates")
    participants_last_fetch_date: Optional[datetime] = Field(default=None, description="The date and time when parties/attorneys were last updated from the Court. Formatted as YYYY-MM-DDTHH:MM:SS+ZZ:zz, Note: This is currently applicable for Federal PACER cases since we have an option to exclude parties and fetch only latest docket entries when updating cases to save PACER fees.", alias="participantsLastFetchDate")
    source_data_status: Optional[StrictStr] = Field(default=None, description="The status of source data of case. If the value of sourceDataStatus is SOURCE_DEPRECATED then it means that the Case has been migrated from old court site to a new court site and the data being shown in the API response is from a old court site. If the sourceDataStatus is NO_LONGER_AVAILABLE_IN_COURT then it means that a particular case is invalid in the court site.", alias="sourceDataStatus")
    source_case_data: Optional[SourceCaseData] = Field(default=None, alias="sourceCaseData")
    has_documents_with_preview: Optional[StrictBool] = Field(default=None, description="This field will be set to TRUE if atleast one document has a preview.", alias="hasDocumentsWithPreview")
    export_api: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="When a case is beyond the threshold of entities we provide this link so that the user can request and get all the data of the case with one additional call. This data will be zipped and sent via a webhoook.", alias="exportAPI")
    case_stats: Optional[CaseStats] = Field(default=None, alias="caseStats")
    parties: Optional[Parties] = None
    attorneys: Optional[Attorneys] = None
    judges: Optional[Judges] = None
    docket_entries: Optional[DocketEntries] = Field(default=None, alias="docketEntries")
    hearings: Optional[Hearings] = None
    case_documents: Optional[CaseDocuments] = Field(default=None, alias="caseDocuments")
    related_cases: Optional[RelatedCases] = Field(default=None, alias="relatedCases")
    __properties: ClassVar[List[str]] = ["object", "caseId", "url", "caseNumber", "caseName", "filedDate", "hasOnlyMetaInfo", "courtServiceStatusId", "courtServiceStatusAPI", "court", "courtLocation", "caseType", "chargeArray", "caseStatus", "causeOfActionArray", "firstFetchDate", "lastFetchDate", "lastFetchDateWithUpdates", "participantsLastFetchDate", "sourceDataStatus", "sourceCaseData", "hasDocumentsWithPreview", "exportAPI", "caseStats", "parties", "attorneys", "judges", "docketEntries", "hearings", "caseDocuments", "relatedCases"]

    @field_validator('source_data_status')
    def source_data_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['NO_LONGER_AVAILABLE_IN_COURT', 'null']):
            raise ValueError("must be one of enum values ('NO_LONGER_AVAILABLE_IN_COURT', 'null')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Case from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of court
        if self.court:
            _dict['court'] = self.court.to_dict()
        # override the default output from pydantic by calling `to_dict()` of court_location
        if self.court_location:
            _dict['courtLocation'] = self.court_location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of case_type
        if self.case_type:
            _dict['caseType'] = self.case_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in charge_array (list)
        _items = []
        if self.charge_array:
            for _item in self.charge_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['chargeArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of case_status
        if self.case_status:
            _dict['caseStatus'] = self.case_status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in cause_of_action_array (list)
        _items = []
        if self.cause_of_action_array:
            for _item in self.cause_of_action_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['causeOfActionArray'] = _items
        # override the default output from pydantic by calling `to_dict()` of source_case_data
        if self.source_case_data:
            _dict['sourceCaseData'] = self.source_case_data.to_dict()
        # override the default output from pydantic by calling `to_dict()` of case_stats
        if self.case_stats:
            _dict['caseStats'] = self.case_stats.to_dict()
        # override the default output from pydantic by calling `to_dict()` of parties
        if self.parties:
            _dict['parties'] = self.parties.to_dict()
        # override the default output from pydantic by calling `to_dict()` of attorneys
        if self.attorneys:
            _dict['attorneys'] = self.attorneys.to_dict()
        # override the default output from pydantic by calling `to_dict()` of judges
        if self.judges:
            _dict['judges'] = self.judges.to_dict()
        # override the default output from pydantic by calling `to_dict()` of docket_entries
        if self.docket_entries:
            _dict['docketEntries'] = self.docket_entries.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hearings
        if self.hearings:
            _dict['hearings'] = self.hearings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of case_documents
        if self.case_documents:
            _dict['caseDocuments'] = self.case_documents.to_dict()
        # override the default output from pydantic by calling `to_dict()` of related_cases
        if self.related_cases:
            _dict['relatedCases'] = self.related_cases.to_dict()
        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        # set to None if case_name (nullable) is None
        # and model_fields_set contains the field
        if self.case_name is None and "case_name" in self.model_fields_set:
            _dict['caseName'] = None

        # set to None if court_service_status_id (nullable) is None
        # and model_fields_set contains the field
        if self.court_service_status_id is None and "court_service_status_id" in self.model_fields_set:
            _dict['courtServiceStatusId'] = None

        # set to None if court_service_status_api (nullable) is None
        # and model_fields_set contains the field
        if self.court_service_status_api is None and "court_service_status_api" in self.model_fields_set:
            _dict['courtServiceStatusAPI'] = None

        # set to None if participants_last_fetch_date (nullable) is None
        # and model_fields_set contains the field
        if self.participants_last_fetch_date is None and "participants_last_fetch_date" in self.model_fields_set:
            _dict['participantsLastFetchDate'] = None

        # set to None if source_data_status (nullable) is None
        # and model_fields_set contains the field
        if self.source_data_status is None and "source_data_status" in self.model_fields_set:
            _dict['sourceDataStatus'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Case from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'Case',
            "caseId": obj.get("caseId"),
            "url": obj.get("url"),
            "caseNumber": obj.get("caseNumber"),
            "caseName": obj.get("caseName"),
            "filedDate": obj.get("filedDate"),
            "hasOnlyMetaInfo": obj.get("hasOnlyMetaInfo"),
            "courtServiceStatusId": obj.get("courtServiceStatusId"),
            "courtServiceStatusAPI": obj.get("courtServiceStatusAPI"),
            "court": Court.from_dict(obj["court"]) if obj.get("court") is not None else None,
            "courtLocation": CourtLocation.from_dict(obj["courtLocation"]) if obj.get("courtLocation") is not None else None,
            "caseType": CaseType.from_dict(obj["caseType"]) if obj.get("caseType") is not None else None,
            "chargeArray": [CaseCharge.from_dict(_item) for _item in obj["chargeArray"]] if obj.get("chargeArray") is not None else None,
            "caseStatus": CaseStatus.from_dict(obj["caseStatus"]) if obj.get("caseStatus") is not None else None,
            "causeOfActionArray": [CaseCauseOfAction.from_dict(_item) for _item in obj["causeOfActionArray"]] if obj.get("causeOfActionArray") is not None else None,
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate"),
            "lastFetchDateWithUpdates": obj.get("lastFetchDateWithUpdates"),
            "participantsLastFetchDate": obj.get("participantsLastFetchDate"),
            "sourceDataStatus": obj.get("sourceDataStatus"),
            "sourceCaseData": SourceCaseData.from_dict(obj["sourceCaseData"]) if obj.get("sourceCaseData") is not None else None,
            "hasDocumentsWithPreview": obj.get("hasDocumentsWithPreview"),
            "exportAPI": obj.get("exportAPI"),
            "caseStats": CaseStats.from_dict(obj["caseStats"]) if obj.get("caseStats") is not None else None,
            "parties": Parties.from_dict(obj["parties"]) if obj.get("parties") is not None else None,
            "attorneys": Attorneys.from_dict(obj["attorneys"]) if obj.get("attorneys") is not None else None,
            "judges": Judges.from_dict(obj["judges"]) if obj.get("judges") is not None else None,
            "docketEntries": DocketEntries.from_dict(obj["docketEntries"]) if obj.get("docketEntries") is not None else None,
            "hearings": Hearings.from_dict(obj["hearings"]) if obj.get("hearings") is not None else None,
            "caseDocuments": CaseDocuments.from_dict(obj["caseDocuments"]) if obj.get("caseDocuments") is not None else None,
            "relatedCases": RelatedCases.from_dict(obj["relatedCases"]) if obj.get("relatedCases") is not None else None
        })
        return _obj





# coding: utf-8

"""
    UniCourt Enterprise APIs

    <button><a href=\"/developers/enterpriseapi/api/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button> 

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from unicourt.model.source_charge_additional_data import SourceChargeAdditionalData
from typing import Optional, Set
from typing_extensions import Self

class SourceCharge(BaseModel):
    """
    Source charge data from the source site.
    """ # noqa: E501
    object: Optional[Annotated[str, Field(min_length=12, strict=True, max_length=12)]] = Field(default='SourceCharge', description="Name of the object")
    source_charge_raw: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Raw charge data from the source site.", alias="sourceChargeRaw")
    source_charge: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Charge data from the source site.", alias="sourceCharge")
    is_visible: Optional[StrictBool] = Field(default=None, description="Signifies if the charge is currently isVisible or not for the case.", alias="isVisible")
    source_statute: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Statute of a charge.", alias="sourceStatute")
    source_charge_degree: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Charge degree data from the source site.", alias="sourceChargeDegree")
    source_charge_severity: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Charge severity data from the source site.", alias="sourceChargeSeverity")
    source_charge_additional_data_array: Optional[List[SourceChargeAdditionalData]] = Field(default=None, description="Additional data related to the charge which is available in the source site.", alias="sourceChargeAdditionalDataArray")
    first_fetch_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="When this charge was first fetched from the court site.", alias="firstFetchDate")
    last_fetch_date: Optional[Annotated[str, Field(min_length=25, strict=True, max_length=25)]] = Field(default=None, description="When this charge was last fetched from the court site.", alias="lastFetchDate")
    __properties: ClassVar[List[str]] = ["object", "sourceChargeRaw", "sourceCharge", "isVisible", "sourceStatute", "sourceChargeDegree", "sourceChargeSeverity", "sourceChargeAdditionalDataArray", "firstFetchDate", "lastFetchDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SourceCharge from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in source_charge_additional_data_array (list)
        _items = []
        if self.source_charge_additional_data_array:
            for _item in self.source_charge_additional_data_array:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sourceChargeAdditionalDataArray'] = _items
        # set to None if source_charge (nullable) is None
        # and model_fields_set contains the field
        if self.source_charge is None and "source_charge" in self.model_fields_set:
            _dict['sourceCharge'] = None

        # set to None if source_statute (nullable) is None
        # and model_fields_set contains the field
        if self.source_statute is None and "source_statute" in self.model_fields_set:
            _dict['sourceStatute'] = None

        # set to None if source_charge_degree (nullable) is None
        # and model_fields_set contains the field
        if self.source_charge_degree is None and "source_charge_degree" in self.model_fields_set:
            _dict['sourceChargeDegree'] = None

        # set to None if source_charge_severity (nullable) is None
        # and model_fields_set contains the field
        if self.source_charge_severity is None and "source_charge_severity" in self.model_fields_set:
            _dict['sourceChargeSeverity'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SourceCharge from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'SourceCharge',
            "sourceChargeRaw": obj.get("sourceChargeRaw"),
            "sourceCharge": obj.get("sourceCharge"),
            "isVisible": obj.get("isVisible"),
            "sourceStatute": obj.get("sourceStatute"),
            "sourceChargeDegree": obj.get("sourceChargeDegree"),
            "sourceChargeSeverity": obj.get("sourceChargeSeverity"),
            "sourceChargeAdditionalDataArray": [SourceChargeAdditionalData.from_dict(_item) for _item in obj["sourceChargeAdditionalDataArray"]] if obj.get("sourceChargeAdditionalDataArray") is not None else None,
            "firstFetchDate": obj.get("firstFetchDate"),
            "lastFetchDate": obj.get("lastFetchDate")
        })
        return _obj


